@@ -3,9 +3,11 @@
 const char *curl_url_strerror(CURLUcode);
 #define CURLINFO_EFFECTIVE_METHOD CURLINFO_STRING + 58
 #define CURL_HTTP_VERSION_3 30
+#define CURLMOPT_MAX_CONCURRENT_STREAMS 16
+#define HAS_MAX_STREAMS 1
 #define HAS_CURL_EASY_OPTION 1
 #define HAS_CURL_PARSER_STRERROR 1
-#define HAS_CURLINFO_EFFECTIVE_METHOD
+#define HAS_CURLINFO_EFFECTIVE_METHOD 1
 
 #ifndef CURLINC_OPTIONS_H
 #define CURLINC_OPTIONS_H
